/*
 * Copyright 2020 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package android.app.appsearch;

import java.util.List;

/**
 * This class represents one of the results obtained from an AppSearch query.
 *
 * <p>This allows clients to obtain:
 *
 * <ul>
 *   <li>The document which matched, using {@link #getGenericDocument}
 *   <li>Information about which properties in the document matched, and "snippet" information
 *       containing textual summaries of the document's matches, using {@link #getMatchInfos}
 * </ul>
 *
 * <p>"Snippet" refers to a substring of text from the content of document that is returned as a
 * part of search result.
 *
 * @see android.app.appsearch.SearchResults
 */

@SuppressWarnings({"unchecked", "deprecation", "all"})
public final class SearchResult {

SearchResult() { throw new RuntimeException("Stub!"); }

/**
 * Contains the matching {@link android.app.appsearch.GenericDocument GenericDocument}.
 *
 * @return Document object which matched the query.

 * This value cannot be {@code null}.
 */

@android.annotation.NonNull
public android.app.appsearch.GenericDocument getGenericDocument() { throw new RuntimeException("Stub!"); }

/**
 * Returns a list of {@link android.app.appsearch.SearchResult.MatchInfo MatchInfo}s providing information about how the document in {@link
 * #getGenericDocument} matched the query.
 *
 * @return List of matches based on {@link android.app.appsearch.SearchSpec SearchSpec}. If snippeting is disabled using {@link android.app.appsearch.SearchSpec.Builder#setSnippetCount      } or {@link android.app.appsearch.SearchSpec.Builder#setSnippetCountPerProperty      }, for all results after that value, this
 *     method returns an empty list.

 * This value cannot be {@code null}.
 */

@android.annotation.NonNull
public java.util.List<android.app.appsearch.SearchResult.MatchInfo> getMatchInfos() { throw new RuntimeException("Stub!"); }

/**
 * Contains the package name of the app that stored the {@link android.app.appsearch.GenericDocument GenericDocument}.
 *
 * @return Package name that stored the document

 * This value cannot be {@code null}.
 */

@android.annotation.NonNull
public java.lang.String getPackageName() { throw new RuntimeException("Stub!"); }

/**
 * Contains the database name that stored the {@link android.app.appsearch.GenericDocument GenericDocument}.
 *
 * @return Name of the database within which the document is stored

 * This value cannot be {@code null}.
 */

@android.annotation.NonNull
public java.lang.String getDatabaseName() { throw new RuntimeException("Stub!"); }

/**
 * Returns the ranking signal of the {@link android.app.appsearch.GenericDocument GenericDocument}, according to the ranking strategy
 * set in {@link android.app.appsearch.SearchSpec.Builder#setRankingStrategy(int) SearchSpec.Builder#setRankingStrategy(int)}.
 *
 * <p>The meaning of the ranking signal and its value is determined by the selected ranking
 * strategy:
 *
 * <ul>
 *   <li>{@link android.app.appsearch.SearchSpec#RANKING_STRATEGY_NONE SearchSpec#RANKING_STRATEGY_NONE} - this value will be 0
 *   <li>{@link android.app.appsearch.SearchSpec#RANKING_STRATEGY_DOCUMENT_SCORE SearchSpec#RANKING_STRATEGY_DOCUMENT_SCORE} - the value returned by calling
 *       {@link android.app.appsearch.GenericDocument#getScore() GenericDocument#getScore()} on the document returned by {@link
 *       #getGenericDocument()}
 *   <li>{@link android.app.appsearch.SearchSpec#RANKING_STRATEGY_CREATION_TIMESTAMP SearchSpec#RANKING_STRATEGY_CREATION_TIMESTAMP} - the value returned by calling
 *       {@link android.app.appsearch.GenericDocument#getCreationTimestampMillis() GenericDocument#getCreationTimestampMillis()} on the document returned by {@link
 *       #getGenericDocument()}
 *   <li>{@link android.app.appsearch.SearchSpec#RANKING_STRATEGY_RELEVANCE_SCORE SearchSpec#RANKING_STRATEGY_RELEVANCE_SCORE} - an arbitrary double value where a
 *       higher value means more relevant
 *   <li>{@link android.app.appsearch.SearchSpec#RANKING_STRATEGY_USAGE_COUNT SearchSpec#RANKING_STRATEGY_USAGE_COUNT} - the number of times usage has been
 *       reported for the document returned by {@link #getGenericDocument()}
 *   <li>{@link android.app.appsearch.SearchSpec#RANKING_STRATEGY_USAGE_LAST_USED_TIMESTAMP SearchSpec#RANKING_STRATEGY_USAGE_LAST_USED_TIMESTAMP} - the timestamp of the
 *       most recent usage that has been reported for the document returned by {@link
 *       #getGenericDocument()}
 * </ul>
 *
 * @return Ranking signal of the document
 */

public double getRankingSignal() { throw new RuntimeException("Stub!"); }

/**
 * Gets a list of {@link android.app.appsearch.SearchResult SearchResult} joined from the join operation.
 *
 * <p>These joined documents match the outer document as specified in the {@link android.app.appsearch.JoinSpec JoinSpec} with
 * parentPropertyExpression and childPropertyExpression. They are ordered according to the
 * {@link android.app.appsearch.JoinSpec#getNestedSearchSpec JoinSpec#getNestedSearchSpec}, and as many SearchResults as specified by {@link android.app.appsearch.JoinSpec#getMaxJoinedResultCount  } will be returned. If no {@link android.app.appsearch.JoinSpec JoinSpec} was specified,
 * this returns an empty list.
 *
 * <p>This method is inefficient to call repeatedly, as new {@link android.app.appsearch.SearchResult SearchResult} objects are
 * created each time.
 *
 * @return a List of SearchResults containing joined documents.

 * This value cannot be {@code null}.
 */

@android.annotation.NonNull
public java.util.List<android.app.appsearch.SearchResult> getJoinedResults() { throw new RuntimeException("Stub!"); }
/** Builder for {@link android.app.appsearch.SearchResult SearchResult} objects. */

@SuppressWarnings({"unchecked", "deprecation", "all"})
public static final class Builder {

/**
 * Constructs a new builder for {@link android.app.appsearch.SearchResult SearchResult} objects.
 *
 * @param packageName the package name the matched document belongs to
 * This value cannot be {@code null}.
 * @param databaseName the database name the matched document belongs to.

 * This value cannot be {@code null}.
 */

public Builder(@android.annotation.NonNull java.lang.String packageName, @android.annotation.NonNull java.lang.String databaseName) { throw new RuntimeException("Stub!"); }

/**
 * Sets the document which matched.
 * @param document This value cannot be {@code null}.
 * @return This value cannot be {@code null}.
 */

@android.annotation.NonNull
public android.app.appsearch.SearchResult.Builder setGenericDocument(@android.annotation.NonNull android.app.appsearch.GenericDocument document) { throw new RuntimeException("Stub!"); }

/**
 * Adds another match to this SearchResult.
 * @param matchInfo This value cannot be {@code null}.
 * @return This value cannot be {@code null}.
 */

@android.annotation.NonNull
public android.app.appsearch.SearchResult.Builder addMatchInfo(@android.annotation.NonNull android.app.appsearch.SearchResult.MatchInfo matchInfo) { throw new RuntimeException("Stub!"); }

/**
 * Sets the ranking signal of the matched document in this SearchResult.
 * @return This value cannot be {@code null}.
 */

@android.annotation.NonNull
public android.app.appsearch.SearchResult.Builder setRankingSignal(double rankingSignal) { throw new RuntimeException("Stub!"); }

/**
 * Adds a {@link android.app.appsearch.SearchResult SearchResult} that was joined by the {@link android.app.appsearch.JoinSpec JoinSpec}.
 *
 * @param joinedResult The joined SearchResult to add.
 
 * This value cannot be {@code null}.
 * @return This value cannot be {@code null}.
 */

@android.annotation.NonNull
public android.app.appsearch.SearchResult.Builder addJoinedResult(@android.annotation.NonNull android.app.appsearch.SearchResult joinedResult) { throw new RuntimeException("Stub!"); }

/**
 * Constructs a new {@link android.app.appsearch.SearchResult SearchResult}.
 * @return This value cannot be {@code null}.
 */

@android.annotation.NonNull
public android.app.appsearch.SearchResult build() { throw new RuntimeException("Stub!"); }
}

/**
 * This class represents match objects for any Snippets that might be present in {@link android.app.appsearch.SearchResults SearchResults} from a query. Using this class, the user can get:
 *
 * <ul>
 *   <li>the full text - all of the text in that String property
 *   <li>the exact term match - the 'term' (full word) that matched the query
 *   <li>the subterm match - the portion of the matched term that appears in the query
 *   <li>a suggested text snippet - a portion of the full text surrounding the exact term match,
 *       set to term boundaries. The size of the snippet is specified in {@link android.app.appsearch.SearchSpec.Builder#setMaxSnippetSize        }
 * </ul>
 *
 * for each match in the document.
 *
 * <p>Class Example 1:
 *
 * <p>A document contains the following text in property "subject":
 *
 * <p>"A commonly used fake word is foo. Another nonsense word that’s used a lot is bar."
 *
 * <p>If the queryExpression is "foo" and {@link android.app.appsearch.SearchSpec#getMaxSnippetSize SearchSpec#getMaxSnippetSize} is 10,
 *
 * <ul>
 *   <li>{@link android.app.appsearch.SearchResult.MatchInfo#getPropertyPath() MatchInfo#getPropertyPath()} returns "subject"
 *   <li>{@link android.app.appsearch.SearchResult.MatchInfo#getFullText() MatchInfo#getFullText()} returns "A commonly used fake word is foo. Another
 *       nonsense word that’s used a lot is bar."
 *   <li>{@link android.app.appsearch.SearchResult.MatchInfo#getExactMatchRange() MatchInfo#getExactMatchRange()} returns [29, 32]
 *   <li>{@link android.app.appsearch.SearchResult.MatchInfo#getExactMatch() MatchInfo#getExactMatch()} returns "foo"
 *   <li>{@link android.app.appsearch.SearchResult.MatchInfo#getSubmatchRange() MatchInfo#getSubmatchRange()} returns [29, 32]
 *   <li>{@link android.app.appsearch.SearchResult.MatchInfo#getSubmatch() MatchInfo#getSubmatch()} returns "foo"
 *   <li>{@link android.app.appsearch.SearchResult.MatchInfo#getSnippetRange() MatchInfo#getSnippetRange()} returns [26, 33]
 *   <li>{@link android.app.appsearch.SearchResult.MatchInfo#getSnippet() MatchInfo#getSnippet()} returns "is foo."
 * </ul>
 *
 * <p>
 *
 * <p>Class Example 2:
 *
 * <p>A document contains one property named "subject" and one property named "sender" which
 * contains a "name" property.
 *
 * <p>In this case, we will have 2 property paths: {@code sender.name} and {@code subject}.
 *
 * <p>Let {@code sender.name = "Test Name Jr."} and {@code subject = "Testing 1 2 3"}
 *
 * <p>If the queryExpression is "Test" with {@link android.app.appsearch.SearchSpec#TERM_MATCH_PREFIX SearchSpec#TERM_MATCH_PREFIX} and {@link android.app.appsearch.SearchSpec#getMaxSnippetSize  } is 10. We will have 2 matches:
 *
 * <p>Match-1
 *
 * <ul>
 *   <li>{@link android.app.appsearch.SearchResult.MatchInfo#getPropertyPath() MatchInfo#getPropertyPath()} returns "sender.name"
 *   <li>{@link android.app.appsearch.SearchResult.MatchInfo#getFullText() MatchInfo#getFullText()} returns "Test Name Jr."
 *   <li>{@link android.app.appsearch.SearchResult.MatchInfo#getExactMatchRange() MatchInfo#getExactMatchRange()} returns [0, 4]
 *   <li>{@link android.app.appsearch.SearchResult.MatchInfo#getExactMatch() MatchInfo#getExactMatch()} returns "Test"
 *   <li>{@link android.app.appsearch.SearchResult.MatchInfo#getSubmatchRange() MatchInfo#getSubmatchRange()} returns [0, 4]
 *   <li>{@link android.app.appsearch.SearchResult.MatchInfo#getSubmatch() MatchInfo#getSubmatch()} returns "Test"
 *   <li>{@link android.app.appsearch.SearchResult.MatchInfo#getSnippetRange() MatchInfo#getSnippetRange()} returns [0, 9]
 *   <li>{@link android.app.appsearch.SearchResult.MatchInfo#getSnippet() MatchInfo#getSnippet()} returns "Test Name"
 * </ul>
 *
 * <p>Match-2
 *
 * <ul>
 *   <li>{@link android.app.appsearch.SearchResult.MatchInfo#getPropertyPath() MatchInfo#getPropertyPath()} returns "subject"
 *   <li>{@link android.app.appsearch.SearchResult.MatchInfo#getFullText() MatchInfo#getFullText()} returns "Testing 1 2 3"
 *   <li>{@link android.app.appsearch.SearchResult.MatchInfo#getExactMatchRange() MatchInfo#getExactMatchRange()} returns [0, 7]
 *   <li>{@link android.app.appsearch.SearchResult.MatchInfo#getExactMatch() MatchInfo#getExactMatch()} returns "Testing"
 *   <li>{@link android.app.appsearch.SearchResult.MatchInfo#getSubmatchRange() MatchInfo#getSubmatchRange()} returns [0, 4]
 *   <li>{@link android.app.appsearch.SearchResult.MatchInfo#getSubmatch() MatchInfo#getSubmatch()} returns "Test"
 *   <li>{@link android.app.appsearch.SearchResult.MatchInfo#getSnippetRange() MatchInfo#getSnippetRange()} returns [0, 9]
 *   <li>{@link android.app.appsearch.SearchResult.MatchInfo#getSnippet() MatchInfo#getSnippet()} returns "Testing 1"
 * </ul>
 */

@SuppressWarnings({"unchecked", "deprecation", "all"})
public static final class MatchInfo {

MatchInfo() { throw new RuntimeException("Stub!"); }

/**
 * Gets the property path corresponding to the given entry.
 *
 * <p>A property path is a '.' - delimited sequence of property names indicating which
 * property in the document these snippets correspond to.
 *
 * <p>Example properties: 'body', 'sender.name', 'sender.emailaddress', etc. For class
 * example 1 this returns "subject"

 * @return This value cannot be {@code null}.
 */

@android.annotation.NonNull
public java.lang.String getPropertyPath() { throw new RuntimeException("Stub!"); }

/**
 * Gets a {@link android.app.appsearch.PropertyPath PropertyPath} object representing the property path corresponding to the
 * given entry.
 *
 * <p>Methods such as {@link android.app.appsearch.GenericDocument#getPropertyDocument GenericDocument#getPropertyDocument} accept a path as a string
 * rather than a {@link android.app.appsearch.PropertyPath PropertyPath} object. However, you may want to manipulate the path
 * before getting a property document. This method returns a {@link android.app.appsearch.PropertyPath PropertyPath} rather
 * than a String for easier path manipulation, which can then be converted to a String.
 *
 * @see #getPropertyPath
 * @see android.app.appsearch.PropertyPath

 * @return This value cannot be {@code null}.
 */

@android.annotation.NonNull
public android.app.appsearch.PropertyPath getPropertyPathObject() { throw new RuntimeException("Stub!"); }

/**
 * Gets the full text corresponding to the given entry.
 *
 * <p>Class example 1: this returns "A commonly used fake word is foo. Another nonsense word
 * that's used a lot is bar."
 *
 * <p>Class example 2: for the first {@link android.app.appsearch.SearchResult.MatchInfo MatchInfo}, this returns "Test Name Jr." and,
 * for the second {@link android.app.appsearch.SearchResult.MatchInfo MatchInfo}, this returns "Testing 1 2 3".

 * @return This value cannot be {@code null}.
 */

@android.annotation.NonNull
public java.lang.String getFullText() { throw new RuntimeException("Stub!"); }

/**
 * Gets the {@link android.app.appsearch.SearchResult.MatchRange MatchRange} of the exact term of the given entry that matched the query.
 *
 * <p>Class example 1: this returns [29, 32].
 *
 * <p>Class example 2: for the first {@link android.app.appsearch.SearchResult.MatchInfo MatchInfo}, this returns [0, 4] and, for the
 * second {@link android.app.appsearch.SearchResult.MatchInfo MatchInfo}, this returns [0, 7].

 * @return This value cannot be {@code null}.
 */

@android.annotation.NonNull
public android.app.appsearch.SearchResult.MatchRange getExactMatchRange() { throw new RuntimeException("Stub!"); }

/**
 * Gets the exact term of the given entry that matched the query.
 *
 * <p>Class example 1: this returns "foo".
 *
 * <p>Class example 2: for the first {@link android.app.appsearch.SearchResult.MatchInfo MatchInfo}, this returns "Test" and, for the
 * second {@link android.app.appsearch.SearchResult.MatchInfo MatchInfo}, this returns "Testing".

 * @return This value cannot be {@code null}.
 */

@android.annotation.NonNull
public java.lang.CharSequence getExactMatch() { throw new RuntimeException("Stub!"); }

/**
 * Gets the {@link android.app.appsearch.SearchResult.MatchRange MatchRange} of the exact term subsequence of the given entry that matched
 * the query.
 *
 * <p>Class example 1: this returns [29, 32].
 *
 * <p>Class example 2: for the first {@link android.app.appsearch.SearchResult.MatchInfo MatchInfo}, this returns [0, 4] and, for the
 * second {@link android.app.appsearch.SearchResult.MatchInfo MatchInfo}, this returns [0, 4].

 * @return This value cannot be {@code null}.
 */

@android.annotation.NonNull
public android.app.appsearch.SearchResult.MatchRange getSubmatchRange() { throw new RuntimeException("Stub!"); }

/**
 * Gets the exact term subsequence of the given entry that matched the query.
 *
 * <p>Class example 1: this returns "foo".
 *
 * <p>Class example 2: for the first {@link android.app.appsearch.SearchResult.MatchInfo MatchInfo}, this returns "Test" and, for the
 * second {@link android.app.appsearch.SearchResult.MatchInfo MatchInfo}, this returns "Test".

 * @return This value cannot be {@code null}.
 */

@android.annotation.NonNull
public java.lang.CharSequence getSubmatch() { throw new RuntimeException("Stub!"); }

/**
 * Gets the snippet {@link android.app.appsearch.SearchResult.MatchRange MatchRange} corresponding to the given entry.
 *
 * <p>Only populated when set maxSnippetSize > 0 in {@link android.app.appsearch.SearchSpec.Builder#setMaxSnippetSize  }.
 *
 * <p>Class example 1: this returns [29, 41].
 *
 * <p>Class example 2: for the first {@link android.app.appsearch.SearchResult.MatchInfo MatchInfo}, this returns [0, 9] and, for the
 * second {@link android.app.appsearch.SearchResult.MatchInfo MatchInfo}, this returns [0, 13].

 * @return This value cannot be {@code null}.
 */

@android.annotation.NonNull
public android.app.appsearch.SearchResult.MatchRange getSnippetRange() { throw new RuntimeException("Stub!"); }

/**
 * Gets the snippet corresponding to the given entry.
 *
 * <p>Snippet - Provides a subset of the content to display. Only populated when requested
 * maxSnippetSize > 0. The size of this content can be changed by {@link android.app.appsearch.SearchSpec.Builder#setMaxSnippetSize  }. Windowing is centered around the middle of the
 * matched token with content on either side clipped to token boundaries.
 *
 * <p>Class example 1: this returns "foo. Another".
 *
 * <p>Class example 2: for the first {@link android.app.appsearch.SearchResult.MatchInfo MatchInfo}, this returns "Test Name" and, for
 * the second {@link android.app.appsearch.SearchResult.MatchInfo MatchInfo}, this returns "Testing 1 2 3".

 * @return This value cannot be {@code null}.
 */

@android.annotation.NonNull
public java.lang.CharSequence getSnippet() { throw new RuntimeException("Stub!"); }
/** Builder for {@link android.app.appsearch.SearchResult.MatchInfo MatchInfo} objects. */

@SuppressWarnings({"unchecked", "deprecation", "all"})
public static final class Builder {

/**
 * Creates a new {@link android.app.appsearch.SearchResult.MatchInfo.Builder MatchInfo.Builder} reporting a match with the given property
 * path.
 *
 * <p>A property path is a dot-delimited sequence of property names indicating which
 * property in the document these snippets correspond to.
 *
 * <p>Example properties: 'body', 'sender.name', 'sender.emailaddress', etc. For class
 * example 1 this returns "subject".
 *
 * @param propertyPath A dot-delimited sequence of property names indicating which
 *     property in the document these snippets correspond to.

 * This value cannot be {@code null}.
 */

public Builder(@android.annotation.NonNull java.lang.String propertyPath) { throw new RuntimeException("Stub!"); }

/**
 * Sets the exact {@link android.app.appsearch.SearchResult.MatchRange MatchRange} corresponding to the given entry.
 * @param matchRange This value cannot be {@code null}.
 * @return This value cannot be {@code null}.
 */

@android.annotation.NonNull
public android.app.appsearch.SearchResult.MatchInfo.Builder setExactMatchRange(@android.annotation.NonNull android.app.appsearch.SearchResult.MatchRange matchRange) { throw new RuntimeException("Stub!"); }

/**
 * Sets the submatch {@link android.app.appsearch.SearchResult.MatchRange MatchRange} corresponding to the given entry.
 * @param matchRange This value cannot be {@code null}.
 * @return This value cannot be {@code null}.
 */

@android.annotation.NonNull
public android.app.appsearch.SearchResult.MatchInfo.Builder setSubmatchRange(@android.annotation.NonNull android.app.appsearch.SearchResult.MatchRange matchRange) { throw new RuntimeException("Stub!"); }

/**
 * Sets the snippet {@link android.app.appsearch.SearchResult.MatchRange MatchRange} corresponding to the given entry.
 * @param matchRange This value cannot be {@code null}.
 * @return This value cannot be {@code null}.
 */

@android.annotation.NonNull
public android.app.appsearch.SearchResult.MatchInfo.Builder setSnippetRange(@android.annotation.NonNull android.app.appsearch.SearchResult.MatchRange matchRange) { throw new RuntimeException("Stub!"); }

/**
 * Constructs a new {@link android.app.appsearch.SearchResult.MatchInfo MatchInfo}.
 * @return This value cannot be {@code null}.
 */

@android.annotation.NonNull
public android.app.appsearch.SearchResult.MatchInfo build() { throw new RuntimeException("Stub!"); }
}

}

/**
 * Class providing the position range of matching information.
 *
 * <p>All ranges are finite, and the left side of the range is always {@code <=} the right side
 * of the range.
 *
 * <p>Example: MatchRange(0, 100) represent a hundred ints from 0 to 99."
 */

@SuppressWarnings({"unchecked", "deprecation", "all"})
public static final class MatchRange {

/**
 * Creates a new immutable range.
 *
 * <p>The endpoints are {@code [start, end)}; that is the range is bounded. {@code start}
 * must be lesser or equal to {@code end}.
 *
 * @param start The start point (inclusive)
 * @param end The end point (exclusive)
 */

public MatchRange(int start, int end) { throw new RuntimeException("Stub!"); }

/** Gets the start point (inclusive). */

public int getStart() { throw new RuntimeException("Stub!"); }

/** Gets the end point (exclusive). */

public int getEnd() { throw new RuntimeException("Stub!"); }

/**
 * {@inheritDoc}

 * @param other This value may be {@code null}.
 */

public boolean equals(@android.annotation.Nullable java.lang.Object other) { throw new RuntimeException("Stub!"); }

/**
 * {@inheritDoc}

 * @return This value cannot be {@code null}.
 */

@android.annotation.NonNull
public java.lang.String toString() { throw new RuntimeException("Stub!"); }

public int hashCode() { throw new RuntimeException("Stub!"); }
}

}

